@@ -5,12 +5,12 @@ use strict;
 
 use vars qw($VERSION);
 
-$VERSION = '0.15';
+$VERSION = '0.16';
 
 use DateTime 0.22;
 use DateTime::LeapSecond;
 
-use Math::BigInt ('lib' => $^O eq 'MSWin32' ? 'Pari,FastCalc' : 'GMP,Pari,FastCalc');
+use Math::BigInt 'lib' => 'GMP,Pari,FastCalc';
 use Params::Validate qw/validate BOOLEAN OBJECT/;
 
 sub _floor {
@@ -98,6 +98,9 @@ sub format_datetime {
     }
 
     if ($self->{type} eq 'bigint') {
+        if ($secs > 2_147_483_647) {
+          $secs = "$secs"; #https://rt.cpan.org/Ticket/Display.html?id=103517
+        }
         $secs = Math::BigInt->new($secs);
     }
 
